@@ -4,11 +4,11 @@ from shutil import copyfileobj
 
 try:
     from urllib.request import urlopen
-except ImportError:  # py27
+except ImportError: # py27
     from urllib import urlopen
 try:
     from urllib.parse import urlparse
-except ImportError:  # py27
+except ImportError: # py27
     from urlparse import urlparse
 
 import requests
@@ -50,16 +50,16 @@ def get_file(fname, origin, cache_dir=None, chunk_size=None):
     fpath = path.join(cache_dir, fname)
 
     if not path.exists(fpath):
-        log.debug("Downloading %s from %s" % (fpath, origin))
+        log.debug("Downloading %s from %s", fpath, origin)
         try:
             d = requests.get(origin, stream=True)
             with tqdm(
-                total=float(d.headers.get("Content-length") or 0),
-                desc=fname,
-                unit="B",
-                unit_scale=True,
-                unit_divisor=1024,
-                leave=False,
+                    total=float(d.headers.get("Content-length") or 0),
+                    desc=fname,
+                    unit="B",
+                    unit_scale=True,
+                    unit_divisor=1024,
+                    leave=False,
             ) as fprog:
                 with open(fpath, "wb") as fo:
                     for chunk in d.iter_content(chunk_size=chunk_size):
@@ -93,7 +93,7 @@ def urlopen_cached(url, outdir, fname=None, mode="rb"):
     if fname is None:
         fname = Path(urlparse(url).path).name
     fout = outdir / fname
-    cache = outdir / (fspath(fname) + ".url")
+    cache = outdir / f"{fspath(fname)}.url"
     if not fout.is_file() or not cache.is_file() or cache.read_text().strip() != url:
         fi = urlopen(url)
         with fout.open("wb") as raw:
